@@ -56,13 +56,24 @@ class Button (Tkinter.Button, RO.AddCallback.TkButtonMixin, CtxMenu.CtxMenuMixin
         SeverityActiveMixin.__init__(self, severity)
     
     def setEnable(self, doEnable):
+        """Enable or disable widget
+
+        Inputs:
+        - doEnable: if True enable widget (set state to normal); otherwise set state to disabled
+
+        Warning: if you want the state to be "active" you must set that explicitly.
+        """
         if doEnable:
-            self["state"] = "normal"
+            self["state"] = Tkinter.NORMAL
         else:
-            self["state"] = "disabled"
+            self["state"] = Tkinter.DISABLED
     
     def getEnable(self):
-        return self["state"] == "normal"
+        """Return True if widget is enabled, False otherwise
+
+        Enabled is defined as the state is not "disabled" (thus "enabled" or "active").
+        """
+        return self["state"] != Tkinter.DISABLED
 
 
 class Radiobutton (Tkinter.Radiobutton, CtxMenu.CtxMenuMixin, SeverityActiveMixin):
@@ -104,7 +115,6 @@ class Radiobutton (Tkinter.Radiobutton, CtxMenu.CtxMenuMixin, SeverityActiveMixi
         if argDict is not None:
             kargs.update(argDict)
         if "width" in kargs:
-            initialWidth = kargs["width"]
             kargs["width"] = self._computeCorrectedWidth(
                 width = kargs["width"],
                 hasBitmap = bool(kargs.get("bitmap", self["bitmap"])),
